pub struct Partition {
pub start: u64,
pub length: u64,
pub kind: PartitionKind,
pub label: Option<String>,
pub uuid: Option<[u8; 16]>,
}Expand description
One partition. start/length are byte values relative to the start of
the whole device.
Fields
start: u64length: u64kind: PartitionKindlabel: Option<String>uuid: Option<[u8; 16]>Implementations
Sourceimpl Partition
impl Partition
Sourcepub fn is_bootable(&self) -> bool
pub fn is_bootable(&self) -> bool
True when this partition is marked bootable in the on-disk table.
- MBR: the active flag is set on the entry (legacy BIOS boots from the active partition).
- GPT: the type GUID is the EFI System Partition GUID or the
LEGACY_BIOS_BOOTABLEattribute bit is set. - Whole: never (no firmware-level bootability for table-less media).